/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvMath.h"
#include "HvControlBinop.h"
#include "HvControlSlice.h"
#include "HvControlIf.h"
#include "HvControlDelay.h"
#include "HvSignalEnvelope.h"
#include "HvSignalVar.h"
#include "HvControlCast.h"
#include "HvControlVar.h"
#include "HvSignalLine.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_NXAfv3Gq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_12B0e5om_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mE7qyQKA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_01EgBpRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jBbAS7R5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eNCxLlCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LqxCp2Iy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fHCv7k4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DnsrlYlX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f4ti73RJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cr3FCqnC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ck0Rddng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AE0jC9q6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nVPKdM3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HZOypY5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_J2TyojGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jHwyP2RP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4FE7RGB3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AR1a1c0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bGOngTvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_biBJGhNL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UPRU6j4P_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_hLbZYuln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AeEpAT0o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N1ayRbsV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gpwNDvmm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RNzRFB3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PWDBzk6f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zpifNcwc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rGkD4PpP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tG86gU8K_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7YJRPG7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aT3lfoF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wg10bJ58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9S0HkxWG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GleAudjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tZgf2Oab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C0ChbpKx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JTN8lgqQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HqHaS7fd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LWkTCpy1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P9C6ZEhq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PH5l1tmY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tui6nrRH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2nRqqGdQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_4kOKEkhp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fIRjiCsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YJnxKqsi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tw5jUB2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dogjNiC6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OJQDKS3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hOTThWvV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8AeVUOwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XwJSMjEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_muM0nbtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vEtf7Xz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tJDnlSrj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QaGAaKUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cPtI8uRH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1Mx42N28_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KiMGpvON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6BNYaQ8C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1QKCo5wt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n0dZm5jN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TS91OfWB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q1ZAEt71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZR7nowvM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vfqMBUr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pg68GAcW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0hLEzRpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GjaaGOry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BoxZZUf4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_chNe6pG5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_hnzmWAWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ct28COXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_98VEQlpC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tGwB0PXu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KjZhZwla_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rrDCh55b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lc912DMb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b58lKEPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uTD7MxV8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mUVN0rqS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AEt6uz3q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DFTdEx0D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fvXK8erK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KntJPMvC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_YEVHDXHi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F334nszc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6VXapjRF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9DWWzFJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HpjnXNUw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lJxIGGz5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c4HkkVwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oVwLE1Ha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_79CjKcJl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XZnyEOTa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_faZUPyoT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ShAMziJ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gXxD4zxR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JcYPVEeL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_vy2zgsX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fFKguQG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bXc1DJIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yBAHWck5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gWPnQAXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9hY1irzM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yhDwD8lc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aRimDdkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JX5kNL8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ndZnYIPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E7tF6mSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6rDCNUcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_n2skRyXX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sRWKMKEM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_abpyiIwD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y4eXXJjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q3W10TkS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tGXpwDEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LISDmIEw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4dwE7YDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6E9jLFJO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m98tWqX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t6dQ7WQv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J3Uwg69O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_THDh6CnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CP2kNBpt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kxZOUoCV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iTdVLdOu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ovOWXv8P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_40T2ROd5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kkotWTNS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hokC3dKw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cf4IusDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lk05ksr8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lYMbjihB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NZZBsipQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L3vNeDa8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MGsiWksX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9xTCSEMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xnitpEEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uyX5is88_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4ZNZq7WA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_AFzS5Gld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5UoI40W3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gEHfzn2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_shWtylOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LfJI4WFg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0mnQjac3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bmvWkfly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CWc5fusJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_diIqZPbc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sFz28pFA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AQ0q5C1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_W0zYQ1XV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3oDR1wK7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CmsextrV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_CCbcCBAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6RyHdK9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eTb1dBFg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L5G8UXAR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IPDgaolV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sgu3o28R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xHmojged_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JUBOyujz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M3G9XnKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wNqrZUBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dHMwir2Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8dTZdMv9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tkk29sZW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GpNpJbZr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_AxTvKKVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vs1dWUpK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XwqFrsur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dwYdjGoh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ydRoCImY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rSJ4LbsF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XO2YNQTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_45psA1bo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AbNQq6id_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A0uaC5Gp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LoooepjO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Nt4v9tnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_UxdB7E3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_t78nvIvR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wjZKYO1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AkChsQPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6GLvL5Ot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zi5Ms2im_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4e3jGKuQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v50MNS6e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xd5KEBul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tKylpbHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pltPcqqK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o4162KM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iRTayUEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q2rAwyFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n6U6cR8V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CRa5TaA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WrLdQ1yR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ogfo023j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g7z6lnrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NvFngSH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PMCaMYVL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sAC1eJOP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aTcvLbHl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sxw5DRWF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RK8WkRF1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eYPw2guY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tmfioCJS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iYEuBtYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aYxjlRos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fld8FXBX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o63gkQ9E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SrAcfRC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cwF7VlrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M6PgJLVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hhs5FVzM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DJJqZzwl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4Qmg5CRm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ztFnk87k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GOBb67Yc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mvz6VbHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_238n5SPL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n3RZkGvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NbD9lPfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QcFwRg3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XLrGXNV8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dfGg4tXy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lnZFkZ3y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9Zj2R8P0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WmbL0fo5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4USToOgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bNperq8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FicI9U4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DxmgH9OM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LOpzXwtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ObnW9npj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_79GfuLmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bElrxDbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zBGsOup0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KJNVmSLX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_69GttSIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EcMwZCd6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XrIOyxcv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kXhqZMvH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_pkE0eDTA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FTymNYAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oiEXfWzw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZKHdENXn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_jXgW3GL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w3JvsjNS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EFZQ1zr7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_W1t2I48x_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7ohjFONn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rR8iNHVv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9zYhNhrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oZsLK4iv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_rEJ1GFfx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SaxmckDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cx8pqawT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6uCDOLhF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ufLcuWri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9BnGf5BW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_60orH9fx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ogrIf3cU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JCXFZgNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bYMjZ9gR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_Hxly4jhx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_PsiloXPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MSH8urDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MFl2gXsF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lvxycbWT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sa2zSzvu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lrNFqdWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tJoVIJMM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6JtYkah6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zei1Dbak_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UuMaZo2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FzsX0JwQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gn2rhCuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pS1tZAwO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c4BvIImo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VVI1z8nV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_CIYEmP3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jnfEZPgA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_MMn67OUn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D3kpj8UU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wn1HCVk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_irNnAgO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wgcyUKR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AVJrCd6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WR4zPiow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9t13E0et_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gUIyaf5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kTQYUk8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VDRTZ3mm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jJvyOW3B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_foTrBnLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WO5lTmbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_U3NjPPlM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_1ymk5l8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LOBJujGt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_afCBWTRi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SDgUDey3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RdZEVHKW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hhKTC6UA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_U0GzmyZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uJu9Dw4k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oOGmf249_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_XdsSGap3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X0buuvfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U5ZyrDDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cbWL89Im_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6QtnNM65_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qRQ5ndNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kpAxRFcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qxlh1Jc5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wh5Tmb3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nvELSZ0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NKd7d2Xh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mbGNJYFh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6syRjANG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_d1wVqubv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Bie8df0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6JqVAdJn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2opWeR0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yqosc4cA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jJtEKDaE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_45jiLYqs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cwnoFYKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bWu4Jui0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xZ2YHc3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vf2BqasV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W6uQPob7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kjQslsUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bj2o3LDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BjZ6OqWt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wZE71WD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wTQBiJ18_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QRyU3SO7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GNVcmi5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0QILP2zn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UtCgYsEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AJjsVFZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xO6Hl9kp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tJ4H3ioc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X2dxYJim_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hs0ogUvf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2JzgQfrm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oaU21ZD8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Je9D8DqP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wSUb777j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vwi1bO02_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V3Qv3s8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AKJImw08_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W5mj0DiX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zBZRFddF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bq0WHUmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UwmsqIVa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Jj3Fkgzi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E5c1zbGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4l778TGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_K7KFd2gW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DJtMkpAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_V2QRYCAP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_GGHykz8E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sxV1bGF8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IwNuUWrR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DPZtwE2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jMDxLaUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HKr1AOqa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xpbQrUOt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6MD8gJav_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Umk35F8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0Upntaxe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g8MhLJJD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Z7kRDBFL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Sxv9uCbD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3N6cYRDU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wsBh8ij3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qu3JiUVx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EyqzkvbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8ieJrV30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FPjs6J7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GoaCxHGE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_isb6zBn9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bq1cNNTS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JyozKQwM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0mlWFwOU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_usHB8ob6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xhmS0PcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jXeqyzCi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EkB3jfvd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_B8D4ut2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zikaymUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_25mmVhJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5YOadPJQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RZXUo6Ga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1frbEwSN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LYEadQNN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4RRSSeOT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FVKfzzDX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eKgDfb1B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xv1a4lVG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JlLoNn85_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nWCDubSB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_33fiUL9e_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ECKcutRk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5wTQ4uxo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wb4mipee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tWWWozey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eBuIQTaO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z2kxjzej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u3aJiyoe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mhWQuXsi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rULOlMLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b3HU9zOK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LGGKeDZi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZVgm6pF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qZWIBvhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_59AD6USF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_H5kLR4ze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4KoWI7bo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VUSJsZ0z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X0HO8rwf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MrUlLkEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C2DiGOt2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BSWGqgH6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nwzC4F9f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oD9Uz5iX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wTvcXOg2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jk1XDvF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1M5TyF6X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9dTHzcd6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5qnU2TXg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_yBfGJyhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WaRNQb69_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_REusxZfN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0COHQ2cB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oZCKD2Ko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ts8Rr8Z4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MhomLYdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jQMlsimY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WhGN7eIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7OAkic6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nfr7lm4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_84MNTWam_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jo9QnHMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4lEbCRG7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_qyd6M3Oc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JrIkeARe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1qJUAI0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PUFj9wC5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wf94JoRN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LH6Gz4M6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JwPzSnyT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SHWVVVGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XUlmBScn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XLQkJMLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_78JyVveC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VWY7axqa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SMnnIeIS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PdObEsxB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_5C1OZLGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YI84yMRc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NEPv3rdp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xZjKkOCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OchpcC2T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sl8EVLcq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YK657MSE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wr2ZYeGO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_20P4kL6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZOC8wWnL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sgCLJ0mk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OXaTiVS0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HNKTcRIA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KED5n51j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qqsl3S0A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K1t2lmZN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qj60ozsW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5WoMOCkS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CHTIpwIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ez5q7pr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qWAcDqzN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UmzarJVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IAtNlhCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gC7vmOI7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ixfvvbNw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L1uUhYaF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r4gCTw7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zGb0btzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ik8ELlOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1CbPDac8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vmsR23DV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9S5V3R5H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zOxtxdKI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WE5P4aVE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dz9iZwLZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DLgm6yUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Cx8dMvNX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dct0bC8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_499y1xUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zOC84OBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lajSOsUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_359KmXIO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4I4qey8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sDRSgIeL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hmLmAfzt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jbSo88CH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4jO32mZg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZoLyEFqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iBfFgThV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KhXo4Tin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hkp3gGyu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xdYSqmfe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hbOtcUvN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LcbznL1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QpPWmLrV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2rpGWo8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_eze7S1Pp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_yOhqptjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9oNx8QO2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_DudcGVwU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mpUm9IxL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_dCQloc4V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_inWTKTtc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GxWn1W0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JNqmJnhZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_m4JBasaL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ce3bLnVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_aDJN3aXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_nZ4j7eAN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_mm67xk0y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KQBu0saC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EKolbYnN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YrjeF0oD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_dhNBTFZ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bvqRjded_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IexPsCle_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IME7BVgg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_HxLHS27I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uWhwlU1t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cv2AME0m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uFc9evk9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_89AFu0BV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_FxtWK3Rd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_1ZnTEuiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_SnEnyBoq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ma1SbOqL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uDpMrULb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pcsg7gwl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LzEcU9gO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WLrwgXBy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cn0QIHVa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_exWnKprb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wvKofL4e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QAty0K05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UJJGw1Fy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w0nT78C9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2df5Apek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yqJG5i42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lXTirnFD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_WO9uFden_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jQSn8eSv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UL5yTva8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7PWTlMuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8VLu78Wl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZJKIm951_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eLJUffUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_luaHGsby_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wbRAqN3z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uvLXxnI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2ZBQiOIP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AH7zIC2p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e97ymrGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vl7rvJXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_I6LuVADi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kOkiwTo0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d01VxaYz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ABb6u6xL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HjQpb36f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fWh0NbD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FQtQ2y9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n7supUWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4BnWVqox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_491Qt7Er_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nPCZwVyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9pbEquGk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UgLtLkwC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iDaOvZat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VP780tfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eWekESSh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1sWwBzIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JImvYzex_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Tqwn1RXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ahjJNi0s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sMtu4ipE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qGIwO80O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xpd3Sb4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RhJiKJ0q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ogx7dj3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WauzXo4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_c90cMDux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4rD0QJEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SUtJbBAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9kABAFpo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fcoOKuhc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zber9d1f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6iEV6qGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_N7PXAEy0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rawpjvjX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_phnN7pNG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5u4V4yLX_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_jq5egv9u;
  SignalLine sLine_gh3TAiPX;
  SignalLine sLine_6o0Irj9C;
  SignalLine sLine_ghKOFxb1;
  SignalLine sLine_nSiOVzT1;
  SignalLine sLine_Dbzt47cc;
  SignalLine sLine_eTi7sI62;
  SignalLine sLine_FjUzco6L;
  SignalLine sLine_pIzFWcdq;
  SignalLine sLine_AtLrx3Uu;
  SignalLine sLine_oChtKpu6;
  SignalLine sLine_yUd5nh7M;
  SignalEnvelope sEnv_Hxly4jhx;
  SignalEnvelope sEnv_PsiloXPw;
  SignalLine sLine_g92ffEJn;
  SignalLine sLine_SexjhENi;
  SignalLine sLine_dBu7QHe5;
  SignalLine sLine_Dwp8PRi8;
  SignalLine sLine_2wwURlBG;
  SignalLine sLine_xW3tBmRS;
  SignalLine sLine_xRCNKAiV;
  SignalLine sLine_2DUKyMnn;
  SignalLine sLine_p4HlA1fN;
  SignalLine sLine_b93oX8Y2;
  SignalLine sLine_5zOCWLRH;
  SignalLine sLine_6MK3CGfV;
  SignalLine sLine_yk3dPYAK;
  SignalLine sLine_9qsjlaBI;
  SignalLine sLine_Ad8CeIzW;
  SignalLine sLine_3V9P6SQX;
  SignalLine sLine_W2INDvIn;
  SignalLine sLine_GOkA6V4A;
  SignalEnvelope sEnv_1ZnTEuiT;
  SignalEnvelope sEnv_SnEnyBoq;
  SignalLine sLine_LdmqfWFX;
  SignalLine sLine_B5I84ytm;
  SignalLine sLine_hpTh4Ytd;
  SignalLine sLine_PnNpVpFW;
  SignalLine sLine_0VYqAjIM;
  SignalLine sLine_knYjdpVR;
  SignalLine sLine_f4TJHnxd;
  SignalLine sLine_qyu3YKcR;
  ControlVar cVar_NXAfv3Gq;
  ControlBinop cBinop_12B0e5om;
  ControlBinop cBinop_mE7qyQKA;
  ControlBinop cBinop_01EgBpRy;
  ControlBinop cBinop_jBbAS7R5;
  ControlBinop cBinop_fHCv7k4r;
  ControlBinop cBinop_f4ti73RJ;
  ControlBinop cBinop_Cr3FCqnC;
  ControlBinop cBinop_ck0Rddng;
  ControlVar cVar_AE0jC9q6;
  ControlVar cVar_nVPKdM3g;
  ControlVar cVar_HZOypY5g;
  ControlVar cVar_J2TyojGf;
  ControlVar cVar_jHwyP2RP;
  ControlBinop cBinop_4FE7RGB3;
  ControlVar cVar_bGOngTvJ;
  ControlVar cVar_biBJGhNL;
  ControlIf cIf_zpifNcwc;
  ControlIf cIf_rGkD4PpP;
  ControlDelay cDelay_7YJRPG7l;
  ControlBinop cBinop_9S0HkxWG;
  ControlBinop cBinop_GleAudjy;
  ControlIf cIf_PH5l1tmY;
  ControlIf cIf_tui6nrRH;
  ControlDelay cDelay_4kOKEkhp;
  ControlBinop cBinop_Tw5jUB2v;
  ControlBinop cBinop_dogjNiC6;
  ControlIf cIf_tJDnlSrj;
  ControlIf cIf_QaGAaKUt;
  ControlDelay cDelay_1Mx42N28;
  ControlBinop cBinop_1QKCo5wt;
  ControlBinop cBinop_n0dZm5jN;
  ControlIf cIf_GjaaGOry;
  ControlIf cIf_BoxZZUf4;
  ControlDelay cDelay_hnzmWAWV;
  ControlBinop cBinop_tGwB0PXu;
  ControlBinop cBinop_KjZhZwla;
  ControlIf cIf_DFTdEx0D;
  ControlIf cIf_fvXK8erK;
  ControlDelay cDelay_YEVHDXHi;
  ControlBinop cBinop_9DWWzFJ6;
  ControlBinop cBinop_HpjnXNUw;
  ControlIf cIf_ShAMziJ0;
  ControlIf cIf_gXxD4zxR;
  ControlDelay cDelay_vy2zgsX4;
  ControlBinop cBinop_yBAHWck5;
  ControlBinop cBinop_gWPnQAXm;
  ControlIf cIf_6rDCNUcj;
  ControlIf cIf_n2skRyXX;
  ControlDelay cDelay_abpyiIwD;
  ControlBinop cBinop_tGXpwDEn;
  ControlBinop cBinop_LISDmIEw;
  ControlIf cIf_CP2kNBpt;
  ControlIf cIf_kxZOUoCV;
  ControlDelay cDelay_ovOWXv8P;
  ControlBinop cBinop_hokC3dKw;
  ControlBinop cBinop_Cf4IusDW;
  ControlIf cIf_xnitpEEu;
  ControlIf cIf_uyX5is88;
  ControlDelay cDelay_AFzS5Gld;
  ControlBinop cBinop_shWtylOV;
  ControlBinop cBinop_LfJI4WFg;
  ControlIf cIf_W0zYQ1XV;
  ControlIf cIf_3oDR1wK7;
  ControlDelay cDelay_CCbcCBAH;
  ControlBinop cBinop_L5G8UXAR;
  ControlBinop cBinop_IPDgaolV;
  ControlIf cIf_8dTZdMv9;
  ControlIf cIf_tkk29sZW;
  ControlDelay cDelay_AxTvKKVZ;
  ControlBinop cBinop_dwYdjGoh;
  ControlBinop cBinop_ydRoCImY;
  ControlIf cIf_Nt4v9tnE;
  ControlIf cIf_UxdB7E3t;
  ControlDelay cDelay_wjZKYO1W;
  ControlBinop cBinop_Zi5Ms2im;
  ControlBinop cBinop_4e3jGKuQ;
  SignalVarf sVarf_dNrnGAbo;
  SignalVarf sVarf_QzO3QeBu;
  SignalVarf sVarf_PnWCif2J;
  SignalVarf sVarf_WMoQyH4B;
  SignalVarf sVarf_goX0loNs;
  SignalVarf sVarf_GVjrAeMz;
  SignalVarf sVarf_GFXNJopk;
  SignalVarf sVarf_QVds9Lo7;
  ControlVar cVar_zBGsOup0;
  ControlSlice cSlice_69GttSIy;
  ControlVar cVar_EcMwZCd6;
  ControlSlice cSlice_pkE0eDTA;
  ControlVar cVar_FTymNYAP;
  ControlSlice cSlice_jXgW3GL5;
  ControlVar cVar_w3JvsjNS;
  ControlSlice cSlice_7ohjFONn;
  ControlVar cVar_rR8iNHVv;
  ControlSlice cSlice_rEJ1GFfx;
  ControlVar cVar_SaxmckDt;
  ControlDelay cDelay_ufLcuWri;
  ControlVar cVar_ogrIf3cU;
  ControlIf cIf_JCXFZgNB;
  ControlIf cIf_bYMjZ9gR;
  ControlBinop cBinop_MSH8urDt;
  ControlBinop cBinop_lvxycbWT;
  ControlBinop cBinop_Sa2zSzvu;
  ControlBinop cBinop_6JtYkah6;
  ControlBinop cBinop_UuMaZo2E;
  ControlSlice cSlice_CIYEmP3v;
  ControlVar cVar_jnfEZPgA;
  SignalVarf sVarf_cahU502u;
  SignalVarf sVarf_dFzvdCcI;
  SignalVarf sVarf_Ulk5uPji;
  SignalVarf sVarf_o6jopTFw;
  SignalVarf sVarf_5Y1IvyHR;
  SignalVarf sVarf_69OhjOjN;
  ControlBinop cBinop_irNnAgO0;
  ControlBinop cBinop_VDRTZ3mm;
  ControlVar cVar_foTrBnLJ;
  ControlVar cVar_WO5lTmbH;
  ControlIf cIf_U0GzmyZV;
  ControlIf cIf_uJu9Dw4k;
  ControlDelay cDelay_XdsSGap3;
  ControlBinop cBinop_cbWL89Im;
  ControlBinop cBinop_6QtnNM65;
  ControlIf cIf_mbGNJYFh;
  ControlIf cIf_6syRjANG;
  ControlDelay cDelay_Bie8df0T;
  ControlBinop cBinop_Yqosc4cA;
  ControlBinop cBinop_jJtEKDaE;
  ControlIf cIf_kjQslsUi;
  ControlIf cIf_bj2o3LDc;
  ControlDelay cDelay_wZE71WD3;
  ControlBinop cBinop_GNVcmi5J;
  ControlBinop cBinop_0QILP2zn;
  ControlIf cIf_2JzgQfrm;
  ControlIf cIf_oaU21ZD8;
  ControlDelay cDelay_wSUb777j;
  ControlBinop cBinop_AKJImw08;
  ControlBinop cBinop_W5mj0DiX;
  ControlIf cIf_K7KFd2gW;
  ControlIf cIf_DJtMkpAy;
  ControlDelay cDelay_GGHykz8E;
  ControlBinop cBinop_DPZtwE2e;
  ControlBinop cBinop_jMDxLaUt;
  ControlIf cIf_Z7kRDBFL;
  ControlIf cIf_Sxv9uCbD;
  ControlDelay cDelay_wsBh8ij3;
  ControlBinop cBinop_8ieJrV30;
  ControlBinop cBinop_FPjs6J7q;
  ControlIf cIf_xhmS0PcF;
  ControlIf cIf_jXeqyzCi;
  ControlDelay cDelay_B8D4ut2b;
  ControlBinop cBinop_5YOadPJQ;
  ControlBinop cBinop_RZXUo6Ga;
  ControlIf cIf_JlLoNn85;
  ControlIf cIf_nWCDubSB;
  ControlDelay cDelay_ECKcutRk;
  ControlBinop cBinop_tWWWozey;
  ControlBinop cBinop_eBuIQTaO;
  ControlIf cIf_ZVgm6pF3;
  ControlIf cIf_qZWIBvhr;
  ControlDelay cDelay_H5kLR4ze;
  ControlBinop cBinop_X0HO8rwf;
  ControlBinop cBinop_MrUlLkEH;
  ControlIf cIf_1M5TyF6X;
  ControlIf cIf_9dTHzcd6;
  ControlDelay cDelay_yBfGJyhl;
  ControlBinop cBinop_0COHQ2cB;
  ControlBinop cBinop_oZCKD2Ko;
  ControlIf cIf_84MNTWam;
  ControlIf cIf_jo9QnHMl;
  ControlDelay cDelay_qyd6M3Oc;
  ControlBinop cBinop_PUFj9wC5;
  ControlBinop cBinop_wf94JoRN;
  ControlIf cIf_VWY7axqa;
  ControlIf cIf_SMnnIeIS;
  ControlDelay cDelay_5C1OZLGU;
  ControlBinop cBinop_xZjKkOCY;
  ControlBinop cBinop_OchpcC2T;
  SignalVarf sVarf_Spazrv2W;
  SignalVarf sVarf_OqwDNWbK;
  SignalVarf sVarf_SyQSIX44;
  SignalVarf sVarf_3InieQot;
  SignalVarf sVarf_0t3PnL7m;
  SignalVarf sVarf_50TjPITs;
  SignalVarf sVarf_ombuZfhn;
  SignalVarf sVarf_Ik54HRX3;
  ControlVar cVar_2rpGWo8G;
  ControlSlice cSlice_yOhqptjE;
  ControlVar cVar_9oNx8QO2;
  ControlSlice cSlice_dCQloc4V;
  ControlVar cVar_inWTKTtc;
  ControlSlice cSlice_m4JBasaL;
  ControlVar cVar_ce3bLnVQ;
  ControlSlice cSlice_mm67xk0y;
  ControlVar cVar_KQBu0saC;
  ControlSlice cSlice_dhNBTFZ1;
  ControlVar cVar_bvqRjded;
  ControlDelay cDelay_HxLHS27I;
  ControlVar cVar_uFc9evk9;
  ControlIf cIf_89AFu0BV;
  ControlIf cIf_FxtWK3Rd;
  ControlBinop cBinop_Ma1SbOqL;
  ControlBinop cBinop_pcsg7gwl;
  ControlBinop cBinop_LzEcU9gO;
  ControlBinop cBinop_exWnKprb;
  ControlBinop cBinop_QAty0K05;
  ControlSlice cSlice_WO9uFden;
  ControlVar cVar_jQSn8eSv;
  SignalVarf sVarf_LTJqkXRE;
  SignalVarf sVarf_fCZrfLAQ;
  SignalVarf sVarf_1ZCKJEhS;
  SignalVarf sVarf_v8hwxjHS;
  SignalVarf sVarf_XNKXj2tx;
  SignalVarf sVarf_UC8fpQuT;
  ControlBinop cBinop_ZJKIm951;
  ControlBinop cBinop_e97ymrGU;
  ControlVar cVar_I6LuVADi;
  SignalVarf sVarf_H9wgMv10;
  SignalVarf sVarf_iXiw9Imv;
  SignalVarf sVarf_rb8LS7vM;
  SignalVarf sVarf_ij5EqgZS;
  ControlBinop cBinop_FQtQ2y9T;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
