/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_jq5egv9u);
  numBytes += sLine_init(&sLine_gh3TAiPX);
  numBytes += sLine_init(&sLine_6o0Irj9C);
  numBytes += sLine_init(&sLine_ghKOFxb1);
  numBytes += sLine_init(&sLine_nSiOVzT1);
  numBytes += sLine_init(&sLine_Dbzt47cc);
  numBytes += sLine_init(&sLine_eTi7sI62);
  numBytes += sLine_init(&sLine_FjUzco6L);
  numBytes += sLine_init(&sLine_pIzFWcdq);
  numBytes += sLine_init(&sLine_AtLrx3Uu);
  numBytes += sLine_init(&sLine_oChtKpu6);
  numBytes += sLine_init(&sLine_yUd5nh7M);
  numBytes += sEnv_init(&sEnv_Hxly4jhx, 512, 256);
  numBytes += sEnv_init(&sEnv_PsiloXPw, 512, 256);
  numBytes += sLine_init(&sLine_g92ffEJn);
  numBytes += sLine_init(&sLine_SexjhENi);
  numBytes += sLine_init(&sLine_dBu7QHe5);
  numBytes += sLine_init(&sLine_Dwp8PRi8);
  numBytes += sLine_init(&sLine_2wwURlBG);
  numBytes += sLine_init(&sLine_xW3tBmRS);
  numBytes += sLine_init(&sLine_xRCNKAiV);
  numBytes += sLine_init(&sLine_2DUKyMnn);
  numBytes += sLine_init(&sLine_p4HlA1fN);
  numBytes += sLine_init(&sLine_b93oX8Y2);
  numBytes += sLine_init(&sLine_5zOCWLRH);
  numBytes += sLine_init(&sLine_6MK3CGfV);
  numBytes += sLine_init(&sLine_yk3dPYAK);
  numBytes += sLine_init(&sLine_9qsjlaBI);
  numBytes += sLine_init(&sLine_Ad8CeIzW);
  numBytes += sLine_init(&sLine_3V9P6SQX);
  numBytes += sLine_init(&sLine_W2INDvIn);
  numBytes += sLine_init(&sLine_GOkA6V4A);
  numBytes += sEnv_init(&sEnv_1ZnTEuiT, 512, 256);
  numBytes += sEnv_init(&sEnv_SnEnyBoq, 512, 256);
  numBytes += sLine_init(&sLine_LdmqfWFX);
  numBytes += sLine_init(&sLine_B5I84ytm);
  numBytes += sLine_init(&sLine_hpTh4Ytd);
  numBytes += sLine_init(&sLine_PnNpVpFW);
  numBytes += sLine_init(&sLine_0VYqAjIM);
  numBytes += sLine_init(&sLine_knYjdpVR);
  numBytes += sLine_init(&sLine_f4TJHnxd);
  numBytes += sLine_init(&sLine_qyu3YKcR);
  numBytes += cVar_init_f(&cVar_NXAfv3Gq, 0.0f);
  numBytes += cVar_init_f(&cVar_AE0jC9q6, 0.0f);
  numBytes += cVar_init_f(&cVar_nVPKdM3g, 0.0f);
  numBytes += cVar_init_f(&cVar_HZOypY5g, 0.0f);
  numBytes += cVar_init_f(&cVar_J2TyojGf, 0.0f);
  numBytes += cVar_init_f(&cVar_jHwyP2RP, 1.0f);
  numBytes += cVar_init_f(&cVar_bGOngTvJ, 0.0f);
  numBytes += cVar_init_f(&cVar_biBJGhNL, 0.0f);
  numBytes += cIf_init(&cIf_zpifNcwc, false);
  numBytes += cIf_init(&cIf_rGkD4PpP, false);
  numBytes += cDelay_init(this, &cDelay_7YJRPG7l, 10.0f);
  numBytes += cIf_init(&cIf_PH5l1tmY, false);
  numBytes += cIf_init(&cIf_tui6nrRH, false);
  numBytes += cDelay_init(this, &cDelay_4kOKEkhp, 10.0f);
  numBytes += cIf_init(&cIf_tJDnlSrj, false);
  numBytes += cIf_init(&cIf_QaGAaKUt, false);
  numBytes += cDelay_init(this, &cDelay_1Mx42N28, 10.0f);
  numBytes += cIf_init(&cIf_GjaaGOry, false);
  numBytes += cIf_init(&cIf_BoxZZUf4, false);
  numBytes += cDelay_init(this, &cDelay_hnzmWAWV, 10.0f);
  numBytes += cIf_init(&cIf_DFTdEx0D, false);
  numBytes += cIf_init(&cIf_fvXK8erK, false);
  numBytes += cDelay_init(this, &cDelay_YEVHDXHi, 10.0f);
  numBytes += cIf_init(&cIf_ShAMziJ0, false);
  numBytes += cIf_init(&cIf_gXxD4zxR, false);
  numBytes += cDelay_init(this, &cDelay_vy2zgsX4, 10.0f);
  numBytes += cIf_init(&cIf_6rDCNUcj, false);
  numBytes += cIf_init(&cIf_n2skRyXX, false);
  numBytes += cDelay_init(this, &cDelay_abpyiIwD, 10.0f);
  numBytes += cIf_init(&cIf_CP2kNBpt, false);
  numBytes += cIf_init(&cIf_kxZOUoCV, false);
  numBytes += cDelay_init(this, &cDelay_ovOWXv8P, 10.0f);
  numBytes += cIf_init(&cIf_xnitpEEu, false);
  numBytes += cIf_init(&cIf_uyX5is88, false);
  numBytes += cDelay_init(this, &cDelay_AFzS5Gld, 10.0f);
  numBytes += cIf_init(&cIf_W0zYQ1XV, false);
  numBytes += cIf_init(&cIf_3oDR1wK7, false);
  numBytes += cDelay_init(this, &cDelay_CCbcCBAH, 10.0f);
  numBytes += cIf_init(&cIf_8dTZdMv9, false);
  numBytes += cIf_init(&cIf_tkk29sZW, false);
  numBytes += cDelay_init(this, &cDelay_AxTvKKVZ, 10.0f);
  numBytes += cIf_init(&cIf_Nt4v9tnE, false);
  numBytes += cIf_init(&cIf_UxdB7E3t, false);
  numBytes += cDelay_init(this, &cDelay_wjZKYO1W, 10.0f);
  numBytes += sVarf_init(&sVarf_dNrnGAbo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QzO3QeBu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PnWCif2J, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WMoQyH4B, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_goX0loNs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GVjrAeMz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GFXNJopk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QVds9Lo7, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_zBGsOup0, 0.0f);
  numBytes += cSlice_init(&cSlice_69GttSIy, 1, -1);
  numBytes += cVar_init_f(&cVar_EcMwZCd6, 1.0f);
  numBytes += cSlice_init(&cSlice_pkE0eDTA, 1, -1);
  numBytes += cVar_init_f(&cVar_FTymNYAP, 0.0f);
  numBytes += cSlice_init(&cSlice_jXgW3GL5, 1, -1);
  numBytes += cVar_init_f(&cVar_w3JvsjNS, 512.0f);
  numBytes += cSlice_init(&cSlice_7ohjFONn, 1, -1);
  numBytes += cVar_init_f(&cVar_rR8iNHVv, 1.0f);
  numBytes += cSlice_init(&cSlice_rEJ1GFfx, 1, -1);
  numBytes += cVar_init_f(&cVar_SaxmckDt, 1.0f);
  numBytes += cDelay_init(this, &cDelay_ufLcuWri, 20.0f);
  numBytes += cVar_init_f(&cVar_ogrIf3cU, 0.0f);
  numBytes += cIf_init(&cIf_JCXFZgNB, false);
  numBytes += cIf_init(&cIf_bYMjZ9gR, false);
  numBytes += cBinop_init(&cBinop_MSH8urDt, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_CIYEmP3v, 1, -1);
  numBytes += cVar_init_f(&cVar_jnfEZPgA, 0.0f);
  numBytes += sVarf_init(&sVarf_cahU502u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dFzvdCcI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ulk5uPji, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o6jopTFw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5Y1IvyHR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_69OhjOjN, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_foTrBnLJ, 0.0f);
  numBytes += cVar_init_f(&cVar_WO5lTmbH, 0.0f);
  numBytes += cIf_init(&cIf_U0GzmyZV, false);
  numBytes += cIf_init(&cIf_uJu9Dw4k, false);
  numBytes += cDelay_init(this, &cDelay_XdsSGap3, 10.0f);
  numBytes += cIf_init(&cIf_mbGNJYFh, false);
  numBytes += cIf_init(&cIf_6syRjANG, false);
  numBytes += cDelay_init(this, &cDelay_Bie8df0T, 10.0f);
  numBytes += cIf_init(&cIf_kjQslsUi, false);
  numBytes += cIf_init(&cIf_bj2o3LDc, false);
  numBytes += cDelay_init(this, &cDelay_wZE71WD3, 10.0f);
  numBytes += cIf_init(&cIf_2JzgQfrm, false);
  numBytes += cIf_init(&cIf_oaU21ZD8, false);
  numBytes += cDelay_init(this, &cDelay_wSUb777j, 10.0f);
  numBytes += cIf_init(&cIf_K7KFd2gW, false);
  numBytes += cIf_init(&cIf_DJtMkpAy, false);
  numBytes += cDelay_init(this, &cDelay_GGHykz8E, 10.0f);
  numBytes += cIf_init(&cIf_Z7kRDBFL, false);
  numBytes += cIf_init(&cIf_Sxv9uCbD, false);
  numBytes += cDelay_init(this, &cDelay_wsBh8ij3, 10.0f);
  numBytes += cIf_init(&cIf_xhmS0PcF, false);
  numBytes += cIf_init(&cIf_jXeqyzCi, false);
  numBytes += cDelay_init(this, &cDelay_B8D4ut2b, 10.0f);
  numBytes += cIf_init(&cIf_JlLoNn85, false);
  numBytes += cIf_init(&cIf_nWCDubSB, false);
  numBytes += cDelay_init(this, &cDelay_ECKcutRk, 10.0f);
  numBytes += cIf_init(&cIf_ZVgm6pF3, false);
  numBytes += cIf_init(&cIf_qZWIBvhr, false);
  numBytes += cDelay_init(this, &cDelay_H5kLR4ze, 10.0f);
  numBytes += cIf_init(&cIf_1M5TyF6X, false);
  numBytes += cIf_init(&cIf_9dTHzcd6, false);
  numBytes += cDelay_init(this, &cDelay_yBfGJyhl, 10.0f);
  numBytes += cIf_init(&cIf_84MNTWam, false);
  numBytes += cIf_init(&cIf_jo9QnHMl, false);
  numBytes += cDelay_init(this, &cDelay_qyd6M3Oc, 10.0f);
  numBytes += cIf_init(&cIf_VWY7axqa, false);
  numBytes += cIf_init(&cIf_SMnnIeIS, false);
  numBytes += cDelay_init(this, &cDelay_5C1OZLGU, 10.0f);
  numBytes += sVarf_init(&sVarf_Spazrv2W, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OqwDNWbK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SyQSIX44, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3InieQot, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0t3PnL7m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_50TjPITs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ombuZfhn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ik54HRX3, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_2rpGWo8G, 0.0f);
  numBytes += cSlice_init(&cSlice_yOhqptjE, 1, -1);
  numBytes += cVar_init_f(&cVar_9oNx8QO2, 1.0f);
  numBytes += cSlice_init(&cSlice_dCQloc4V, 1, -1);
  numBytes += cVar_init_f(&cVar_inWTKTtc, 0.0f);
  numBytes += cSlice_init(&cSlice_m4JBasaL, 1, -1);
  numBytes += cVar_init_f(&cVar_ce3bLnVQ, 512.0f);
  numBytes += cSlice_init(&cSlice_mm67xk0y, 1, -1);
  numBytes += cVar_init_f(&cVar_KQBu0saC, 1.0f);
  numBytes += cSlice_init(&cSlice_dhNBTFZ1, 1, -1);
  numBytes += cVar_init_f(&cVar_bvqRjded, 1.0f);
  numBytes += cDelay_init(this, &cDelay_HxLHS27I, 20.0f);
  numBytes += cVar_init_f(&cVar_uFc9evk9, 0.0f);
  numBytes += cIf_init(&cIf_89AFu0BV, false);
  numBytes += cIf_init(&cIf_FxtWK3Rd, false);
  numBytes += cBinop_init(&cBinop_Ma1SbOqL, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_WO9uFden, 1, -1);
  numBytes += cVar_init_f(&cVar_jQSn8eSv, 0.0f);
  numBytes += sVarf_init(&sVarf_LTJqkXRE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fCZrfLAQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1ZCKJEhS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v8hwxjHS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XNKXj2tx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UC8fpQuT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_I6LuVADi, 0.0f);
  numBytes += sVarf_init(&sVarf_H9wgMv10, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iXiw9Imv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rb8LS7vM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ij5EqgZS, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_Hxly4jhx);
  sEnv_free(&sEnv_PsiloXPw);
  sEnv_free(&sEnv_1ZnTEuiT);
  sEnv_free(&sEnv_SnEnyBoq);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ahjJNi0s_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xpd3Sb4y_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5u4V4yLX_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qGIwO80O_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Tqwn1RXd_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RhJiKJ0q_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JImvYzex_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1sWwBzIk_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c90cMDux_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ogx7dj3u_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9kABAFpo_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SUtJbBAi_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WauzXo4s_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4rD0QJEo_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6iEV6qGU_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fcoOKuhc_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_phnN7pNG_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rawpjvjX_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zber9d1f_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_N7PXAEy0_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sMtu4ipE_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_NXAfv3Gq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HjQpb36f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_12B0e5om_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mE7qyQKA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_mE7qyQKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_01EgBpRy_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_01EgBpRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jBbAS7R5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_jBbAS7R5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eNCxLlCj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LqxCp2Iy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_eNCxLlCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fHCv7k4r_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LqxCp2Iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DnsrlYlX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_fHCv7k4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Cr3FCqnC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DnsrlYlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_f4ti73RJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_f4ti73RJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ck0Rddng_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Cr3FCqnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kOkiwTo0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_ck0Rddng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d01VxaYz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_AE0jC9q6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ABb6u6xL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_nVPKdM3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n7supUWU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_HZOypY5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fWh0NbD3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_J2TyojGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4BnWVqox_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_jHwyP2RP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4FE7RGB3_sendMessage);
  cMsg_491Qt7Er_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_4FE7RGB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jHwyP2RP, 1, m, &cVar_jHwyP2RP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AR1a1c0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nPCZwVyZ_sendMessage(_c, 0, m);
  cMsg_9pbEquGk_sendMessage(_c, 0, m);
  cMsg_UgLtLkwC_sendMessage(_c, 0, m);
  cMsg_eWekESSh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_bGOngTvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D3kpj8UU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_biBJGhNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wn1HCVk0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_UPRU6j4P_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hLbZYuln_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AeEpAT0o_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N1ayRbsV_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gpwNDvmm_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RNzRFB3w_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PWDBzk6f_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_hLbZYuln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q2rAwyFt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_AeEpAT0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n6U6cR8V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_N1ayRbsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CRa5TaA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_gpwNDvmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WrLdQ1yR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_RNzRFB3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ogfo023j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_PWDBzk6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g7z6lnrJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_zpifNcwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_P9C6ZEhq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_rGkD4PpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LWkTCpy1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_tG86gU8K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aT3lfoF5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aT3lfoF5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7YJRPG7l, 1, m, &cDelay_7YJRPG7l_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wg10bJ58_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_7YJRPG7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7YJRPG7l, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zpifNcwc, 0, m, &cIf_zpifNcwc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aT3lfoF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7YJRPG7l, 0, m, &cDelay_7YJRPG7l_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wg10bJ58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7YJRPG7l, 0, m, &cDelay_7YJRPG7l_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_9S0HkxWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HqHaS7fd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JTN8lgqQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GleAudjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tZgf2Oab_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C0ChbpKx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tZgf2Oab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zpifNcwc, 1, m, &cIf_zpifNcwc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_C0ChbpKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tG86gU8K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_JTN8lgqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rGkD4PpP, 0, m, &cIf_rGkD4PpP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HqHaS7fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rGkD4PpP, 1, m, &cIf_rGkD4PpP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LWkTCpy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ghKOFxb1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_P9C6ZEhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ghKOFxb1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_PH5l1tmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vEtf7Xz8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_tui6nrRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_muM0nbtq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_2nRqqGdQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fIRjiCsY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fIRjiCsY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4kOKEkhp, 1, m, &cDelay_4kOKEkhp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YJnxKqsi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_4kOKEkhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4kOKEkhp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PH5l1tmY, 0, m, &cIf_PH5l1tmY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fIRjiCsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4kOKEkhp, 0, m, &cDelay_4kOKEkhp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YJnxKqsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4kOKEkhp, 0, m, &cDelay_4kOKEkhp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Tw5jUB2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XwJSMjEK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8AeVUOwX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dogjNiC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hOTThWvV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OJQDKS3w_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OJQDKS3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2nRqqGdQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_hOTThWvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PH5l1tmY, 1, m, &cIf_PH5l1tmY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8AeVUOwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tui6nrRH, 0, m, &cIf_tui6nrRH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XwJSMjEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tui6nrRH, 1, m, &cIf_tui6nrRH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_muM0nbtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eTi7sI62, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_vEtf7Xz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eTi7sI62, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_tJDnlSrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0hLEzRpk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_QaGAaKUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Pg68GAcW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_cPtI8uRH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KiMGpvON_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KiMGpvON_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1Mx42N28, 1, m, &cDelay_1Mx42N28_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6BNYaQ8C_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_1Mx42N28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1Mx42N28, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tJDnlSrj, 0, m, &cIf_tJDnlSrj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KiMGpvON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Mx42N28, 0, m, &cDelay_1Mx42N28_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6BNYaQ8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Mx42N28, 0, m, &cDelay_1Mx42N28_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1QKCo5wt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vfqMBUr5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZR7nowvM_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_n0dZm5jN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TS91OfWB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q1ZAEt71_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TS91OfWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tJDnlSrj, 1, m, &cIf_tJDnlSrj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Q1ZAEt71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cPtI8uRH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_ZR7nowvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QaGAaKUt, 0, m, &cIf_QaGAaKUt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vfqMBUr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QaGAaKUt, 1, m, &cIf_QaGAaKUt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Pg68GAcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AtLrx3Uu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0hLEzRpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AtLrx3Uu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_GjaaGOry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AEt6uz3q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_BoxZZUf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mUVN0rqS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_chNe6pG5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ct28COXZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ct28COXZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hnzmWAWV, 1, m, &cDelay_hnzmWAWV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_98VEQlpC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_hnzmWAWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hnzmWAWV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GjaaGOry, 0, m, &cIf_GjaaGOry_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ct28COXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hnzmWAWV, 0, m, &cDelay_hnzmWAWV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_98VEQlpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hnzmWAWV, 0, m, &cDelay_hnzmWAWV_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tGwB0PXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uTD7MxV8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b58lKEPl_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KjZhZwla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rrDCh55b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lc912DMb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rrDCh55b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GjaaGOry, 1, m, &cIf_GjaaGOry_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lc912DMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_chNe6pG5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_b58lKEPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BoxZZUf4, 0, m, &cIf_BoxZZUf4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_uTD7MxV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BoxZZUf4, 1, m, &cIf_BoxZZUf4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mUVN0rqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nSiOVzT1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_AEt6uz3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nSiOVzT1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_DFTdEx0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_faZUPyoT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_fvXK8erK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XZnyEOTa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_KntJPMvC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_F334nszc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_F334nszc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YEVHDXHi, 1, m, &cDelay_YEVHDXHi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6VXapjRF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_YEVHDXHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YEVHDXHi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_DFTdEx0D, 0, m, &cIf_DFTdEx0D_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_F334nszc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YEVHDXHi, 0, m, &cDelay_YEVHDXHi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6VXapjRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YEVHDXHi, 0, m, &cDelay_YEVHDXHi_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_9DWWzFJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79CjKcJl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oVwLE1Ha_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_HpjnXNUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c4HkkVwG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lJxIGGz5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lJxIGGz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KntJPMvC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_c4HkkVwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DFTdEx0D, 1, m, &cIf_DFTdEx0D_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oVwLE1Ha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fvXK8erK, 0, m, &cIf_fvXK8erK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_79CjKcJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fvXK8erK, 1, m, &cIf_fvXK8erK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XZnyEOTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FjUzco6L, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_faZUPyoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FjUzco6L, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ShAMziJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_E7tF6mSG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_gXxD4zxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ndZnYIPw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_JcYPVEeL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fFKguQG0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fFKguQG0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vy2zgsX4, 1, m, &cDelay_vy2zgsX4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bXc1DJIb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_vy2zgsX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vy2zgsX4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ShAMziJ0, 0, m, &cIf_ShAMziJ0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fFKguQG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vy2zgsX4, 0, m, &cDelay_vy2zgsX4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bXc1DJIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vy2zgsX4, 0, m, &cDelay_vy2zgsX4_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yBAHWck5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JX5kNL8Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aRimDdkR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gWPnQAXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yhDwD8lc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9hY1irzM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9hY1irzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JcYPVEeL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_yhDwD8lc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ShAMziJ0, 1, m, &cIf_ShAMziJ0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aRimDdkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gXxD4zxR, 0, m, &cIf_gXxD4zxR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JX5kNL8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gXxD4zxR, 1, m, &cIf_gXxD4zxR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ndZnYIPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oChtKpu6, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_E7tF6mSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oChtKpu6, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_6rDCNUcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_THDh6CnE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_n2skRyXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_J3Uwg69O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_sRWKMKEM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_y4eXXJjS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_y4eXXJjS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_abpyiIwD, 1, m, &cDelay_abpyiIwD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q3W10TkS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_abpyiIwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_abpyiIwD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6rDCNUcj, 0, m, &cIf_6rDCNUcj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_y4eXXJjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_abpyiIwD, 0, m, &cDelay_abpyiIwD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_q3W10TkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_abpyiIwD, 0, m, &cDelay_abpyiIwD_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tGXpwDEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t6dQ7WQv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m98tWqX2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_LISDmIEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6E9jLFJO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4dwE7YDO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4dwE7YDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sRWKMKEM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_6E9jLFJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6rDCNUcj, 1, m, &cIf_6rDCNUcj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_m98tWqX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n2skRyXX, 0, m, &cIf_n2skRyXX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_t6dQ7WQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n2skRyXX, 1, m, &cIf_n2skRyXX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_J3Uwg69O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dbzt47cc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_THDh6CnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dbzt47cc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_CP2kNBpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9xTCSEMy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_kxZOUoCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MGsiWksX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_iTdVLdOu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_40T2ROd5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_40T2ROd5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ovOWXv8P, 1, m, &cDelay_ovOWXv8P_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkotWTNS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ovOWXv8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ovOWXv8P, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CP2kNBpt, 0, m, &cIf_CP2kNBpt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_40T2ROd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ovOWXv8P, 0, m, &cDelay_ovOWXv8P_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kkotWTNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ovOWXv8P, 0, m, &cDelay_ovOWXv8P_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hokC3dKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L3vNeDa8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NZZBsipQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Cf4IusDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lYMbjihB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lk05ksr8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Lk05ksr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iTdVLdOu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_lYMbjihB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CP2kNBpt, 1, m, &cIf_CP2kNBpt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NZZBsipQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kxZOUoCV, 0, m, &cIf_kxZOUoCV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_L3vNeDa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kxZOUoCV, 1, m, &cIf_kxZOUoCV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MGsiWksX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pIzFWcdq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_9xTCSEMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pIzFWcdq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_xnitpEEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AQ0q5C1Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_uyX5is88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sFz28pFA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_4ZNZq7WA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5UoI40W3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5UoI40W3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AFzS5Gld, 1, m, &cDelay_AFzS5Gld_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gEHfzn2v_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_AFzS5Gld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AFzS5Gld, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xnitpEEu, 0, m, &cIf_xnitpEEu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5UoI40W3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AFzS5Gld, 0, m, &cDelay_AFzS5Gld_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gEHfzn2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AFzS5Gld, 0, m, &cDelay_AFzS5Gld_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_shWtylOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_diIqZPbc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CWc5fusJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_LfJI4WFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0mnQjac3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bmvWkfly_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0mnQjac3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xnitpEEu, 1, m, &cIf_xnitpEEu_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bmvWkfly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4ZNZq7WA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_CWc5fusJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uyX5is88, 0, m, &cIf_uyX5is88_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_diIqZPbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uyX5is88, 1, m, &cIf_uyX5is88_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sFz28pFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yUd5nh7M, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_AQ0q5C1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yUd5nh7M, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_W0zYQ1XV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dHMwir2Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_3oDR1wK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wNqrZUBR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_CmsextrV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6RyHdK9j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6RyHdK9j_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CCbcCBAH, 1, m, &cDelay_CCbcCBAH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eTb1dBFg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_CCbcCBAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CCbcCBAH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_W0zYQ1XV, 0, m, &cIf_W0zYQ1XV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6RyHdK9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CCbcCBAH, 0, m, &cDelay_CCbcCBAH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_eTb1dBFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CCbcCBAH, 0, m, &cDelay_CCbcCBAH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_L5G8UXAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M3G9XnKq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JUBOyujz_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_IPDgaolV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xHmojged_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sgu3o28R_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sgu3o28R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CmsextrV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_xHmojged_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W0zYQ1XV, 1, m, &cIf_W0zYQ1XV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JUBOyujz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3oDR1wK7, 0, m, &cIf_3oDR1wK7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_M3G9XnKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3oDR1wK7, 1, m, &cIf_3oDR1wK7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wNqrZUBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jq5egv9u, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_dHMwir2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jq5egv9u, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_8dTZdMv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LoooepjO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_tkk29sZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_A0uaC5Gp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_GpNpJbZr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Vs1dWUpK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Vs1dWUpK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AxTvKKVZ, 1, m, &cDelay_AxTvKKVZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XwqFrsur_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_AxTvKKVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AxTvKKVZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8dTZdMv9, 0, m, &cIf_8dTZdMv9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Vs1dWUpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AxTvKKVZ, 0, m, &cDelay_AxTvKKVZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XwqFrsur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AxTvKKVZ, 0, m, &cDelay_AxTvKKVZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dwYdjGoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AbNQq6id_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_45psA1bo_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ydRoCImY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rSJ4LbsF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XO2YNQTe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rSJ4LbsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8dTZdMv9, 1, m, &cIf_8dTZdMv9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XO2YNQTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GpNpJbZr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_45psA1bo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tkk29sZW, 0, m, &cIf_tkk29sZW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AbNQq6id_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tkk29sZW, 1, m, &cIf_tkk29sZW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_A0uaC5Gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gh3TAiPX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_LoooepjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gh3TAiPX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Nt4v9tnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iRTayUEC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_UxdB7E3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o4162KM8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_t78nvIvR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AkChsQPz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AkChsQPz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wjZKYO1W, 1, m, &cDelay_wjZKYO1W_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6GLvL5Ot_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wjZKYO1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wjZKYO1W, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Nt4v9tnE, 0, m, &cIf_Nt4v9tnE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AkChsQPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wjZKYO1W, 0, m, &cDelay_wjZKYO1W_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6GLvL5Ot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wjZKYO1W, 0, m, &cDelay_wjZKYO1W_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Zi5Ms2im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pltPcqqK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tKylpbHx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_4e3jGKuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xd5KEBul_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v50MNS6e_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_v50MNS6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_t78nvIvR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Xd5KEBul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Nt4v9tnE, 1, m, &cIf_Nt4v9tnE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tKylpbHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UxdB7E3t, 0, m, &cIf_UxdB7E3t_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pltPcqqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UxdB7E3t, 1, m, &cIf_UxdB7E3t_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_o4162KM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6o0Irj9C, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_iRTayUEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6o0Irj9C, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_q2rAwyFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_eYPw2guY_sendMessage(_c, 0, m);
  cMsg_DJJqZzwl_sendMessage(_c, 0, m);
  cMsg_DxmgH9OM_sendMessage(_c, 0, m);
  cMsg_dfGg4tXy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_n6U6cR8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_eYPw2guY_sendMessage(_c, 0, m);
  cMsg_Hhs5FVzM_sendMessage(_c, 0, m);
  cMsg_LOpzXwtq_sendMessage(_c, 0, m);
  cMsg_XLrGXNV8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CRa5TaA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_tmfioCJS_sendMessage(_c, 0, m);
  cMsg_Hhs5FVzM_sendMessage(_c, 0, m);
  cMsg_dfGg4tXy_sendMessage(_c, 0, m);
  cMsg_bElrxDbd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_WrLdQ1yR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_tmfioCJS_sendMessage(_c, 0, m);
  cMsg_4Qmg5CRm_sendMessage(_c, 0, m);
  cMsg_DxmgH9OM_sendMessage(_c, 0, m);
  cMsg_QcFwRg3i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Ogfo023j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_iYEuBtYi_sendMessage(_c, 0, m);
  cMsg_XLrGXNV8_sendMessage(_c, 0, m);
  cMsg_79GfuLmU_sendMessage(_c, 0, m);
  cMsg_DxmgH9OM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_g7z6lnrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_iYEuBtYi_sendMessage(_c, 0, m);
  cMsg_QcFwRg3i_sendMessage(_c, 0, m);
  cMsg_Hhs5FVzM_sendMessage(_c, 0, m);
  cMsg_ObnW9npj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_NvFngSH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GleAudjy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9S0HkxWG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PMCaMYVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GleAudjy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9S0HkxWG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sAC1eJOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dogjNiC6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Tw5jUB2v_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aTcvLbHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dogjNiC6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Tw5jUB2v_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sxw5DRWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n0dZm5jN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1QKCo5wt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RK8WkRF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n0dZm5jN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1QKCo5wt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eYPw2guY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_NvFngSH8_sendMessage(_c, 0, m);
  cMsg_aTcvLbHl_sendMessage(_c, 0, m);
  cMsg_RK8WkRF1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_tmfioCJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_PMCaMYVL_sendMessage(_c, 0, m);
  cMsg_sAC1eJOP_sendMessage(_c, 0, m);
  cMsg_RK8WkRF1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_iYEuBtYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_PMCaMYVL_sendMessage(_c, 0, m);
  cMsg_aTcvLbHl_sendMessage(_c, 0, m);
  cMsg_sxw5DRWF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_aYxjlRos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KjZhZwla_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tGwB0PXu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fld8FXBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KjZhZwla_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tGwB0PXu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_o63gkQ9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HpjnXNUw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9DWWzFJ6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SrAcfRC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HpjnXNUw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9DWWzFJ6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cwF7VlrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gWPnQAXm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yBAHWck5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_M6PgJLVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gWPnQAXm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yBAHWck5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Hhs5FVzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_fld8FXBX_sendMessage(_c, 0, m);
  cMsg_SrAcfRC8_sendMessage(_c, 0, m);
  cMsg_M6PgJLVy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_DJJqZzwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_fld8FXBX_sendMessage(_c, 0, m);
  cMsg_o63gkQ9E_sendMessage(_c, 0, m);
  cMsg_cwF7VlrJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4Qmg5CRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_aYxjlRos_sendMessage(_c, 0, m);
  cMsg_SrAcfRC8_sendMessage(_c, 0, m);
  cMsg_cwF7VlrJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ztFnk87k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IPDgaolV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_L5G8UXAR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GOBb67Yc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IPDgaolV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_L5G8UXAR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mvz6VbHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ydRoCImY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dwYdjGoh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_238n5SPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ydRoCImY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dwYdjGoh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_n3RZkGvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4e3jGKuQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Zi5Ms2im_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NbD9lPfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4e3jGKuQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Zi5Ms2im_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QcFwRg3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_ztFnk87k_sendMessage(_c, 0, m);
  cMsg_238n5SPL_sendMessage(_c, 0, m);
  cMsg_NbD9lPfs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_XLrGXNV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_GOBb67Yc_sendMessage(_c, 0, m);
  cMsg_mvz6VbHe_sendMessage(_c, 0, m);
  cMsg_NbD9lPfs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_dfGg4tXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_GOBb67Yc_sendMessage(_c, 0, m);
  cMsg_238n5SPL_sendMessage(_c, 0, m);
  cMsg_n3RZkGvF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_lnZFkZ3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LISDmIEw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tGXpwDEn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9Zj2R8P0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LISDmIEw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tGXpwDEn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WmbL0fo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Cf4IusDW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hokC3dKw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4USToOgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Cf4IusDW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hokC3dKw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bNperq8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LfJI4WFg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_shWtylOV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FicI9U4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LfJI4WFg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_shWtylOV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DxmgH9OM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_9Zj2R8P0_sendMessage(_c, 0, m);
  cMsg_4USToOgE_sendMessage(_c, 0, m);
  cMsg_FicI9U4z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_LOpzXwtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_9Zj2R8P0_sendMessage(_c, 0, m);
  cMsg_WmbL0fo5_sendMessage(_c, 0, m);
  cMsg_bNperq8Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ObnW9npj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_lnZFkZ3y_sendMessage(_c, 0, m);
  cMsg_WmbL0fo5_sendMessage(_c, 0, m);
  cMsg_FicI9U4z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_79GfuLmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_aYxjlRos_sendMessage(_c, 0, m);
  cMsg_o63gkQ9E_sendMessage(_c, 0, m);
  cMsg_M6PgJLVy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bElrxDbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_lnZFkZ3y_sendMessage(_c, 0, m);
  cMsg_4USToOgE_sendMessage(_c, 0, m);
  cMsg_bNperq8Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_zBGsOup0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wgcyUKR1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_KJNVmSLX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_69GttSIy, 0, m, &cSlice_69GttSIy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_W1t2I48x_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_69GttSIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XrIOyxcv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XrIOyxcv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_EcMwZCd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XrIOyxcv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_XrIOyxcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ogx7dj3u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_kXhqZMvH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pkE0eDTA, 0, m, &cSlice_pkE0eDTA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZKHdENXn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_pkE0eDTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oiEXfWzw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oiEXfWzw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_FTymNYAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oiEXfWzw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_oiEXfWzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4rD0QJEo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_ZKHdENXn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jXgW3GL5, 0, m, &cSlice_jXgW3GL5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KJNVmSLX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_jXgW3GL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EFZQ1zr7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EFZQ1zr7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_w3JvsjNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EFZQ1zr7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_EFZQ1zr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c90cMDux_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_W1t2I48x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7ohjFONn, 0, m, &cSlice_7ohjFONn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oZsLK4iv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_7ohjFONn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9zYhNhrO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9zYhNhrO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_rR8iNHVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9zYhNhrO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_9zYhNhrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WauzXo4s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_oZsLK4iv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rEJ1GFfx, 0, m, &cSlice_rEJ1GFfx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VVI1z8nV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_rEJ1GFfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cx8pqawT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cx8pqawT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_SaxmckDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cx8pqawT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_cx8pqawT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SUtJbBAi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_6uCDOLhF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9BnGf5BW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9BnGf5BW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ufLcuWri, 1, m, &cDelay_ufLcuWri_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_60orH9fx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ufLcuWri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ufLcuWri, m);
  cMsg_9t13E0et_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_9BnGf5BW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ufLcuWri, 0, m, &cDelay_ufLcuWri_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_60orH9fx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ufLcuWri, 0, m, &cDelay_ufLcuWri_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_ogrIf3cU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MSH8urDt, HV_BINOP_SUBTRACT, 0, m, &cBinop_MSH8urDt_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_JCXFZgNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_c4BvIImo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_bYMjZ9gR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_c4BvIImo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_Hxly4jhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ogrIf3cU, 0, m, &cVar_ogrIf3cU_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_PsiloXPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pS1tZAwO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gn2rhCuU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FzsX0JwQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_MSH8urDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MFl2gXsF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MFl2gXsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_lvxycbWT_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_lvxycbWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_UuMaZo2E_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Sa2zSzvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tJoVIJMM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lrNFqdWy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lrNFqdWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zei1Dbak_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_tJoVIJMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JCXFZgNB, 1, m, &cIf_JCXFZgNB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6JtYkah6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bYMjZ9gR, 1, m, &cIf_bYMjZ9gR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Zei1Dbak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_JCXFZgNB, 0, m, &cIf_JCXFZgNB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UuMaZo2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bYMjZ9gR, 0, m, &cIf_bYMjZ9gR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FzsX0JwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ogrIf3cU, 0, m, &cVar_ogrIf3cU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Gn2rhCuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MSH8urDt, HV_BINOP_SUBTRACT, 1, m, &cBinop_MSH8urDt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pS1tZAwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cMsg_c4BvIImo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g92ffEJn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_VVI1z8nV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CIYEmP3v, 0, m, &cSlice_CIYEmP3v_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_CIYEmP3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MMn67OUn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MMn67OUn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_jnfEZPgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MMn67OUn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_MMn67OUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9kABAFpo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_D3kpj8UU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xW3tBmRS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_wn1HCVk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dwp8PRi8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_irNnAgO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_biBJGhNL, 0, m, &cVar_biBJGhNL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wgcyUKR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2wwURlBG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_AVJrCd6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gUIyaf5d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_WR4zPiow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6uCDOLhF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_9t13E0et_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SexjhENi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_gUIyaf5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SexjhENi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_kTQYUk8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_VDRTZ3mm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_VDRTZ3mm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jJvyOW3B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_jJvyOW3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dBu7QHe5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_foTrBnLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7PWTlMuF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_WO5lTmbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8VLu78Wl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_U3NjPPlM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1ymk5l8X_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LOBJujGt_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_afCBWTRi_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SDgUDey3_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RdZEVHKW_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hhKTC6UA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_1ymk5l8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OXaTiVS0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_LOBJujGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HNKTcRIA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_afCBWTRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KED5n51j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_SDgUDey3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qqsl3S0A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_RdZEVHKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K1t2lmZN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_hhKTC6UA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qj60ozsW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_U0GzmyZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NKd7d2Xh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_uJu9Dw4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nvELSZ0F_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_oOGmf249_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_X0buuvfu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_X0buuvfu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XdsSGap3, 1, m, &cDelay_XdsSGap3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U5ZyrDDa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_XdsSGap3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XdsSGap3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_U0GzmyZV, 0, m, &cIf_U0GzmyZV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_X0buuvfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XdsSGap3, 0, m, &cDelay_XdsSGap3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_U5ZyrDDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XdsSGap3, 0, m, &cDelay_XdsSGap3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cbWL89Im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qxlh1Jc5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wh5Tmb3u_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6QtnNM65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kpAxRFcC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qRQ5ndNs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qRQ5ndNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oOGmf249_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_kpAxRFcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U0GzmyZV, 1, m, &cIf_U0GzmyZV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Qxlh1Jc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uJu9Dw4k, 1, m, &cIf_uJu9Dw4k_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Wh5Tmb3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uJu9Dw4k, 0, m, &cIf_uJu9Dw4k_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nvELSZ0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b93oX8Y2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NKd7d2Xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b93oX8Y2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_mbGNJYFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W6uQPob7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_6syRjANG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vf2BqasV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_d1wVqubv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6JqVAdJn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6JqVAdJn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Bie8df0T, 1, m, &cDelay_Bie8df0T_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2opWeR0R_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Bie8df0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Bie8df0T, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mbGNJYFh, 0, m, &cIf_mbGNJYFh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6JqVAdJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bie8df0T, 0, m, &cDelay_Bie8df0T_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2opWeR0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bie8df0T, 0, m, &cDelay_Bie8df0T_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Yqosc4cA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xZ2YHc3V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bWu4Jui0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_jJtEKDaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cwnoFYKj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_45jiLYqs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_45jiLYqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_d1wVqubv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_cwnoFYKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mbGNJYFh, 1, m, &cIf_mbGNJYFh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bWu4Jui0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6syRjANG, 0, m, &cIf_6syRjANG_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xZ2YHc3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6syRjANG, 1, m, &cIf_6syRjANG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vf2BqasV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yk3dPYAK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_W6uQPob7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yk3dPYAK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_kjQslsUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hs0ogUvf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_bj2o3LDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_X2dxYJim_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_BjZ6OqWt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wTQBiJ18_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wTQBiJ18_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wZE71WD3, 1, m, &cDelay_wZE71WD3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QRyU3SO7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wZE71WD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wZE71WD3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kjQslsUi, 0, m, &cIf_kjQslsUi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wTQBiJ18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wZE71WD3, 0, m, &cDelay_wZE71WD3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QRyU3SO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wZE71WD3, 0, m, &cDelay_wZE71WD3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GNVcmi5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tJ4H3ioc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xO6Hl9kp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0QILP2zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AJjsVFZO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UtCgYsEH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UtCgYsEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BjZ6OqWt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_AJjsVFZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kjQslsUi, 1, m, &cIf_kjQslsUi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xO6Hl9kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bj2o3LDc, 0, m, &cIf_bj2o3LDc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tJ4H3ioc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bj2o3LDc, 1, m, &cIf_bj2o3LDc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_X2dxYJim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3V9P6SQX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_hs0ogUvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3V9P6SQX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_2JzgQfrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4l778TGQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_oaU21ZD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_E5c1zbGS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Je9D8DqP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Vwi1bO02_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Vwi1bO02_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wSUb777j, 1, m, &cDelay_wSUb777j_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V3Qv3s8Q_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wSUb777j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wSUb777j, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2JzgQfrm, 0, m, &cIf_2JzgQfrm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Vwi1bO02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wSUb777j, 0, m, &cDelay_wSUb777j_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_V3Qv3s8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wSUb777j, 0, m, &cDelay_wSUb777j_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AKJImw08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UwmsqIVa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jj3Fkgzi_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_W5mj0DiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zBZRFddF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bq0WHUmC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zBZRFddF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2JzgQfrm, 1, m, &cIf_2JzgQfrm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bq0WHUmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Je9D8DqP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_UwmsqIVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oaU21ZD8, 1, m, &cIf_oaU21ZD8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Jj3Fkgzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oaU21ZD8, 0, m, &cIf_oaU21ZD8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_E5c1zbGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5zOCWLRH, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_4l778TGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5zOCWLRH, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_K7KFd2gW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g8MhLJJD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_DJtMkpAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0Upntaxe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_V2QRYCAP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sxV1bGF8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sxV1bGF8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GGHykz8E, 1, m, &cDelay_GGHykz8E_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IwNuUWrR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_GGHykz8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GGHykz8E, m);
  cIf_onMessage(_c, &Context(_c)->cIf_K7KFd2gW, 0, m, &cIf_K7KFd2gW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sxV1bGF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GGHykz8E, 0, m, &cDelay_GGHykz8E_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IwNuUWrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GGHykz8E, 0, m, &cDelay_GGHykz8E_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DPZtwE2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6MD8gJav_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Umk35F8U_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_jMDxLaUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xpbQrUOt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HKr1AOqa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HKr1AOqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_V2QRYCAP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_xpbQrUOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K7KFd2gW, 1, m, &cIf_K7KFd2gW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6MD8gJav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DJtMkpAy, 1, m, &cIf_DJtMkpAy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Umk35F8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DJtMkpAy, 0, m, &cIf_DJtMkpAy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0Upntaxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9qsjlaBI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_g8MhLJJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9qsjlaBI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Z7kRDBFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_usHB8ob6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Sxv9uCbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0mlWFwOU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_3N6cYRDU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Qu3JiUVx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Qu3JiUVx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wsBh8ij3, 1, m, &cDelay_wsBh8ij3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EyqzkvbH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wsBh8ij3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wsBh8ij3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Z7kRDBFL, 0, m, &cIf_Z7kRDBFL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Qu3JiUVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wsBh8ij3, 0, m, &cDelay_wsBh8ij3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EyqzkvbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wsBh8ij3, 0, m, &cDelay_wsBh8ij3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8ieJrV30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JyozKQwM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bq1cNNTS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FPjs6J7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_isb6zBn9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GoaCxHGE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GoaCxHGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3N6cYRDU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_isb6zBn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z7kRDBFL, 1, m, &cIf_Z7kRDBFL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Bq1cNNTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sxv9uCbD, 0, m, &cIf_Sxv9uCbD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JyozKQwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sxv9uCbD, 1, m, &cIf_Sxv9uCbD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0mlWFwOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W2INDvIn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_usHB8ob6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W2INDvIn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_xhmS0PcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xv1a4lVG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_jXeqyzCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eKgDfb1B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_EkB3jfvd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zikaymUp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zikaymUp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_B8D4ut2b, 1, m, &cDelay_B8D4ut2b_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_25mmVhJP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_B8D4ut2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B8D4ut2b, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xhmS0PcF, 0, m, &cIf_xhmS0PcF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zikaymUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_B8D4ut2b, 0, m, &cDelay_B8D4ut2b_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_25mmVhJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_B8D4ut2b, 0, m, &cDelay_B8D4ut2b_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_5YOadPJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FVKfzzDX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4RRSSeOT_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RZXUo6Ga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LYEadQNN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1frbEwSN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1frbEwSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EkB3jfvd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_LYEadQNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xhmS0PcF, 1, m, &cIf_xhmS0PcF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4RRSSeOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jXeqyzCi, 0, m, &cIf_jXeqyzCi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FVKfzzDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jXeqyzCi, 1, m, &cIf_jXeqyzCi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eKgDfb1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6MK3CGfV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xv1a4lVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6MK3CGfV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_JlLoNn85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LGGKeDZi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_nWCDubSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b3HU9zOK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_33fiUL9e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5wTQ4uxo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5wTQ4uxo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ECKcutRk, 1, m, &cDelay_ECKcutRk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wb4mipee_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ECKcutRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ECKcutRk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JlLoNn85, 0, m, &cIf_JlLoNn85_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5wTQ4uxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ECKcutRk, 0, m, &cDelay_ECKcutRk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wb4mipee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ECKcutRk, 0, m, &cDelay_ECKcutRk_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tWWWozey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rULOlMLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mhWQuXsi_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_eBuIQTaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u3aJiyoe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z2kxjzej_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_z2kxjzej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_33fiUL9e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_u3aJiyoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JlLoNn85, 1, m, &cIf_JlLoNn85_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mhWQuXsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nWCDubSB, 0, m, &cIf_nWCDubSB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rULOlMLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nWCDubSB, 1, m, &cIf_nWCDubSB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_b3HU9zOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ad8CeIzW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_LGGKeDZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ad8CeIzW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ZVgm6pF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jk1XDvF2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_qZWIBvhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wTvcXOg2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_59AD6USF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4KoWI7bo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4KoWI7bo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_H5kLR4ze, 1, m, &cDelay_H5kLR4ze_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VUSJsZ0z_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_H5kLR4ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_H5kLR4ze, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZVgm6pF3, 0, m, &cIf_ZVgm6pF3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4KoWI7bo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_H5kLR4ze, 0, m, &cDelay_H5kLR4ze_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VUSJsZ0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_H5kLR4ze, 0, m, &cDelay_H5kLR4ze_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_X0HO8rwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oD9Uz5iX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nwzC4F9f_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_MrUlLkEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BSWGqgH6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C2DiGOt2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_C2DiGOt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_59AD6USF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_BSWGqgH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZVgm6pF3, 1, m, &cIf_ZVgm6pF3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nwzC4F9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qZWIBvhr, 0, m, &cIf_qZWIBvhr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oD9Uz5iX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qZWIBvhr, 1, m, &cIf_qZWIBvhr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wTvcXOg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GOkA6V4A, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_jk1XDvF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GOkA6V4A, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_1M5TyF6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nfr7lm4T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_9dTHzcd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7OAkic6g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5qnU2TXg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WaRNQb69_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WaRNQb69_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yBfGJyhl, 1, m, &cDelay_yBfGJyhl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_REusxZfN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_yBfGJyhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yBfGJyhl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1M5TyF6X, 0, m, &cIf_1M5TyF6X_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WaRNQb69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yBfGJyhl, 0, m, &cDelay_yBfGJyhl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_REusxZfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yBfGJyhl, 0, m, &cDelay_yBfGJyhl_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0COHQ2cB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WhGN7eIp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jQMlsimY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_oZCKD2Ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ts8Rr8Z4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MhomLYdH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Ts8Rr8Z4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1M5TyF6X, 1, m, &cIf_1M5TyF6X_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MhomLYdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5qnU2TXg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_jQMlsimY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9dTHzcd6, 0, m, &cIf_9dTHzcd6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WhGN7eIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9dTHzcd6, 1, m, &cIf_9dTHzcd6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7OAkic6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xRCNKAiV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_nfr7lm4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xRCNKAiV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_84MNTWam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_78JyVveC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_jo9QnHMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XLQkJMLf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_4lEbCRG7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JrIkeARe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JrIkeARe_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qyd6M3Oc, 1, m, &cDelay_qyd6M3Oc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1qJUAI0k_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_qyd6M3Oc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qyd6M3Oc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_84MNTWam, 0, m, &cIf_84MNTWam_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JrIkeARe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qyd6M3Oc, 0, m, &cDelay_qyd6M3Oc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1qJUAI0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qyd6M3Oc, 0, m, &cDelay_qyd6M3Oc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PUFj9wC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XUlmBScn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SHWVVVGC_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wf94JoRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LH6Gz4M6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JwPzSnyT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LH6Gz4M6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_84MNTWam, 1, m, &cIf_84MNTWam_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JwPzSnyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4lEbCRG7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_SHWVVVGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jo9QnHMl, 0, m, &cIf_jo9QnHMl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XUlmBScn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jo9QnHMl, 1, m, &cIf_jo9QnHMl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XLQkJMLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2DUKyMnn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_78JyVveC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2DUKyMnn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_VWY7axqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sgCLJ0mk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_SMnnIeIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZOC8wWnL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_PdObEsxB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YI84yMRc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YI84yMRc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5C1OZLGU, 1, m, &cDelay_5C1OZLGU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NEPv3rdp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_5C1OZLGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5C1OZLGU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VWY7axqa, 0, m, &cIf_VWY7axqa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YI84yMRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5C1OZLGU, 0, m, &cDelay_5C1OZLGU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NEPv3rdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5C1OZLGU, 0, m, &cDelay_5C1OZLGU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xZjKkOCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_20P4kL6Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wr2ZYeGO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_OchpcC2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YK657MSE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sl8EVLcq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sl8EVLcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PdObEsxB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_YK657MSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VWY7axqa, 1, m, &cIf_VWY7axqa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wr2ZYeGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SMnnIeIS, 0, m, &cIf_SMnnIeIS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_20P4kL6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SMnnIeIS, 1, m, &cIf_SMnnIeIS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZOC8wWnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p4HlA1fN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_sgCLJ0mk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p4HlA1fN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_OXaTiVS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_gC7vmOI7_sendMessage(_c, 0, m);
  cMsg_WE5P4aVE_sendMessage(_c, 0, m);
  cMsg_Hkp3gGyu_sendMessage(_c, 0, m);
  cMsg_sDRSgIeL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HNKTcRIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_gC7vmOI7_sendMessage(_c, 0, m);
  cMsg_zOxtxdKI_sendMessage(_c, 0, m);
  cMsg_xdYSqmfe_sendMessage(_c, 0, m);
  cMsg_4I4qey8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_KED5n51j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_ixfvvbNw_sendMessage(_c, 0, m);
  cMsg_zOxtxdKI_sendMessage(_c, 0, m);
  cMsg_sDRSgIeL_sendMessage(_c, 0, m);
  cMsg_QpPWmLrV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_qqsl3S0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_ixfvvbNw_sendMessage(_c, 0, m);
  cMsg_dz9iZwLZ_sendMessage(_c, 0, m);
  cMsg_Hkp3gGyu_sendMessage(_c, 0, m);
  cMsg_359KmXIO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_K1t2lmZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_L1uUhYaF_sendMessage(_c, 0, m);
  cMsg_4I4qey8c_sendMessage(_c, 0, m);
  cMsg_LcbznL1z_sendMessage(_c, 0, m);
  cMsg_Hkp3gGyu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Qj60ozsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_L1uUhYaF_sendMessage(_c, 0, m);
  cMsg_359KmXIO_sendMessage(_c, 0, m);
  cMsg_zOxtxdKI_sendMessage(_c, 0, m);
  cMsg_hbOtcUvN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_5WoMOCkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6QtnNM65_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cbWL89Im_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CHTIpwIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6QtnNM65_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cbWL89Im_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ez5q7pr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jJtEKDaE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Yqosc4cA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qWAcDqzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jJtEKDaE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Yqosc4cA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UmzarJVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0QILP2zn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GNVcmi5J_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IAtNlhCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0QILP2zn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GNVcmi5J_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gC7vmOI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_5WoMOCkS_sendMessage(_c, 0, m);
  cMsg_qWAcDqzN_sendMessage(_c, 0, m);
  cMsg_IAtNlhCT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ixfvvbNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_CHTIpwIQ_sendMessage(_c, 0, m);
  cMsg_Ez5q7pr1_sendMessage(_c, 0, m);
  cMsg_IAtNlhCT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_L1uUhYaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_CHTIpwIQ_sendMessage(_c, 0, m);
  cMsg_qWAcDqzN_sendMessage(_c, 0, m);
  cMsg_UmzarJVZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_r4gCTw7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W5mj0DiX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AKJImw08_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zGb0btzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W5mj0DiX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AKJImw08_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ik8ELlOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jMDxLaUt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DPZtwE2e_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1CbPDac8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jMDxLaUt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DPZtwE2e_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vmsR23DV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FPjs6J7q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8ieJrV30_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9S5V3R5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FPjs6J7q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8ieJrV30_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zOxtxdKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_zGb0btzC_sendMessage(_c, 0, m);
  cMsg_1CbPDac8_sendMessage(_c, 0, m);
  cMsg_9S5V3R5H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_WE5P4aVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_zGb0btzC_sendMessage(_c, 0, m);
  cMsg_Ik8ELlOJ_sendMessage(_c, 0, m);
  cMsg_vmsR23DV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_dz9iZwLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_r4gCTw7b_sendMessage(_c, 0, m);
  cMsg_1CbPDac8_sendMessage(_c, 0, m);
  cMsg_vmsR23DV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_DLgm6yUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oZCKD2Ko_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0COHQ2cB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Cx8dMvNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oZCKD2Ko_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0COHQ2cB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Dct0bC8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wf94JoRN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PUFj9wC5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_499y1xUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wf94JoRN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PUFj9wC5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zOC84OBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OchpcC2T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xZjKkOCY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lajSOsUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OchpcC2T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xZjKkOCY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_359KmXIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_DLgm6yUL_sendMessage(_c, 0, m);
  cMsg_499y1xUA_sendMessage(_c, 0, m);
  cMsg_lajSOsUj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4I4qey8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Cx8dMvNX_sendMessage(_c, 0, m);
  cMsg_Dct0bC8Y_sendMessage(_c, 0, m);
  cMsg_lajSOsUj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_sDRSgIeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Cx8dMvNX_sendMessage(_c, 0, m);
  cMsg_499y1xUA_sendMessage(_c, 0, m);
  cMsg_zOC84OBk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_hmLmAfzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RZXUo6Ga_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5YOadPJQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jbSo88CH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RZXUo6Ga_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5YOadPJQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4jO32mZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eBuIQTaO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tWWWozey_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZoLyEFqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eBuIQTaO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tWWWozey_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_iBfFgThV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MrUlLkEH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_X0HO8rwf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KhXo4Tin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MrUlLkEH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_X0HO8rwf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Hkp3gGyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_jbSo88CH_sendMessage(_c, 0, m);
  cMsg_ZoLyEFqZ_sendMessage(_c, 0, m);
  cMsg_KhXo4Tin_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xdYSqmfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_jbSo88CH_sendMessage(_c, 0, m);
  cMsg_4jO32mZg_sendMessage(_c, 0, m);
  cMsg_iBfFgThV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_hbOtcUvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_hmLmAfzt_sendMessage(_c, 0, m);
  cMsg_4jO32mZg_sendMessage(_c, 0, m);
  cMsg_KhXo4Tin_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_LcbznL1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_r4gCTw7b_sendMessage(_c, 0, m);
  cMsg_Ik8ELlOJ_sendMessage(_c, 0, m);
  cMsg_9S5V3R5H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_QpPWmLrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_hmLmAfzt_sendMessage(_c, 0, m);
  cMsg_ZoLyEFqZ_sendMessage(_c, 0, m);
  cMsg_iBfFgThV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_2rpGWo8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eLJUffUv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_eze7S1Pp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yOhqptjE, 0, m, &cSlice_yOhqptjE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nZ4j7eAN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_yOhqptjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DudcGVwU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DudcGVwU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_9oNx8QO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DudcGVwU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_DudcGVwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fcoOKuhc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_mpUm9IxL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dCQloc4V, 0, m, &cSlice_dCQloc4V_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JNqmJnhZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_dCQloc4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GxWn1W0R_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GxWn1W0R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_inWTKTtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GxWn1W0R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_GxWn1W0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_N7PXAEy0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_JNqmJnhZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_m4JBasaL, 0, m, &cSlice_m4JBasaL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eze7S1Pp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_m4JBasaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aDJN3aXF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aDJN3aXF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_ce3bLnVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aDJN3aXF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_aDJN3aXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6iEV6qGU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_nZ4j7eAN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mm67xk0y, 0, m, &cSlice_mm67xk0y_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YrjeF0oD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_mm67xk0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EKolbYnN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EKolbYnN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_KQBu0saC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EKolbYnN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_EKolbYnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zber9d1f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_YrjeF0oD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dhNBTFZ1, 0, m, &cSlice_dhNBTFZ1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lXTirnFD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_dhNBTFZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IexPsCle_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IexPsCle_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_bvqRjded_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IexPsCle_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_IexPsCle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rawpjvjX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_IME7BVgg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uWhwlU1t_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uWhwlU1t_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HxLHS27I, 1, m, &cDelay_HxLHS27I_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cv2AME0m_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_HxLHS27I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HxLHS27I, m);
  cMsg_uvLXxnI4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_uWhwlU1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HxLHS27I, 0, m, &cDelay_HxLHS27I_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Cv2AME0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HxLHS27I, 0, m, &cDelay_HxLHS27I_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_uFc9evk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ma1SbOqL, HV_BINOP_SUBTRACT, 0, m, &cBinop_Ma1SbOqL_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_89AFu0BV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yqJG5i42_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_FxtWK3Rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yqJG5i42_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_1ZnTEuiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uFc9evk9, 0, m, &cVar_uFc9evk9_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_SnEnyBoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UJJGw1Fy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2df5Apek_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w0nT78C9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ma1SbOqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uDpMrULb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_uDpMrULb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pcsg7gwl_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_pcsg7gwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_QAty0K05_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_LzEcU9gO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cn0QIHVa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WLrwgXBy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WLrwgXBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wvKofL4e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_cn0QIHVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_89AFu0BV, 1, m, &cIf_89AFu0BV_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_exWnKprb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FxtWK3Rd, 1, m, &cIf_FxtWK3Rd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wvKofL4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_89AFu0BV, 0, m, &cIf_89AFu0BV_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_QAty0K05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FxtWK3Rd, 0, m, &cIf_FxtWK3Rd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UJJGw1Fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_w0nT78C9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uFc9evk9, 0, m, &cVar_uFc9evk9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2df5Apek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ma1SbOqL, HV_BINOP_SUBTRACT, 1, m, &cBinop_Ma1SbOqL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yqJG5i42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LdmqfWFX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_lXTirnFD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WO9uFden, 0, m, &cSlice_WO9uFden_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_WO9uFden_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UL5yTva8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UL5yTva8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_jQSn8eSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UL5yTva8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_UL5yTva8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_phnN7pNG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7PWTlMuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_knYjdpVR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_8VLu78Wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PnNpVpFW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_ZJKIm951_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WO5lTmbH, 0, m, &cVar_WO5lTmbH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eLJUffUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0VYqAjIM, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_luaHGsby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ZBQiOIP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_wbRAqN3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IME7BVgg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_uvLXxnI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B5I84ytm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_2ZBQiOIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B5I84ytm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_AH7zIC2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_e97ymrGU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_e97ymrGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vl7rvJXr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Vl7rvJXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hpTh4Ytd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_I6LuVADi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VP780tfy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_kOkiwTo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qyu3YKcR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_d01VxaYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f4TJHnxd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_ABb6u6xL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1sWwBzIk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HjQpb36f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kXhqZMvH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mpUm9IxL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_fWh0NbD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kXhqZMvH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mpUm9IxL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_FQtQ2y9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AE0jC9q6, 0, m, &cVar_AE0jC9q6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_n7supUWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kXhqZMvH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mpUm9IxL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_4BnWVqox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kXhqZMvH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mpUm9IxL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_491Qt7Er_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kXhqZMvH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mpUm9IxL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_nPCZwVyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_HZOypY5g, 0, m, &cVar_HZOypY5g_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9pbEquGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_nVPKdM3g, 0, m, &cVar_nVPKdM3g_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_J2TyojGf, 0, m, &cVar_J2TyojGf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UgLtLkwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_FQtQ2y9T_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_iDaOvZat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_jHwyP2RP, 0, m, &cVar_jHwyP2RP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VP780tfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_kXhqZMvH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mpUm9IxL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_eWekESSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_I6LuVADi, 0, m, &cVar_I6LuVADi_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_1sWwBzIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_12B0e5om_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_JImvYzex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NXAfv3Gq, 0, m, &cVar_NXAfv3Gq_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Tqwn1RXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_FQtQ2y9T_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_ahjJNi0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HZOypY5g, 0, m, &cVar_HZOypY5g_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_sMtu4ipE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EcMwZCd6, 0, m, &cVar_EcMwZCd6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FTymNYAP, 0, m, &cVar_FTymNYAP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w3JvsjNS, 0, m, &cVar_w3JvsjNS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rR8iNHVv, 0, m, &cVar_rR8iNHVv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SaxmckDt, 0, m, &cVar_SaxmckDt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jnfEZPgA, 0, m, &cVar_jnfEZPgA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9oNx8QO2, 0, m, &cVar_9oNx8QO2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_inWTKTtc, 0, m, &cVar_inWTKTtc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ce3bLnVQ, 0, m, &cVar_ce3bLnVQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KQBu0saC, 0, m, &cVar_KQBu0saC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bvqRjded, 0, m, &cVar_bvqRjded_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jQSn8eSv, 0, m, &cVar_jQSn8eSv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AR1a1c0i_sendMessage);
  cMsg_iDaOvZat_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_qGIwO80O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jHwyP2RP, 0, m, &cVar_jHwyP2RP_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_xpd3Sb4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nVPKdM3g, 0, m, &cVar_nVPKdM3g_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_RhJiKJ0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_J2TyojGf, 0, m, &cVar_J2TyojGf_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Ogx7dj3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bGOngTvJ, 0, m, &cVar_bGOngTvJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_WauzXo4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zBGsOup0, 0, m, &cVar_zBGsOup0_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_c90cMDux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_irNnAgO0_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_4rD0QJEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UPRU6j4P_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AVJrCd6N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WR4zPiow_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_SUtJbBAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Sa2zSzvu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6JtYkah6_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_9kABAFpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kTQYUk8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_fcoOKuhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_foTrBnLJ, 0, m, &cVar_foTrBnLJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_zber9d1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2rpGWo8G, 0, m, &cVar_2rpGWo8G_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_6iEV6qGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_ZJKIm951_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_N7PXAEy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_U3NjPPlM_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_luaHGsby_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wbRAqN3z_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_rawpjvjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LzEcU9gO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_exWnKprb_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_phnN7pNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AH7zIC2p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_5u4V4yLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I6LuVADi, 0, m, &cVar_I6LuVADi_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_H9wgMv10, VIf(I0));
    __hv_varread_f(&sVarf_cahU502u, VOf(Bf0));
    __hv_varread_f(&sVarf_69OhjOjN, VOf(Bf1));
    __hv_varread_f(&sVarf_5Y1IvyHR, VOf(Bf2));
    __hv_varread_f(&sVarf_QzO3QeBu, VOf(Bf3));
    __hv_varread_f(&sVarf_PnWCif2J, VOf(Bf4));
    __hv_varread_f(&sVarf_WMoQyH4B, VOf(Bf5));
    __hv_varread_f(&sVarf_goX0loNs, VOf(Bf6));
    __hv_varwrite_f(&sVarf_dNrnGAbo, VIf(I0));
    __hv_varread_f(&sVarf_GVjrAeMz, VOf(Bf7));
    __hv_line_f(&sLine_jq5egv9u, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_GFXNJopk, VOf(Bf9));
    __hv_line_f(&sLine_gh3TAiPX, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_QVds9Lo7, VOf(Bf8));
    __hv_line_f(&sLine_6o0Irj9C, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_QzO3QeBu, VIf(Bf11));
    __hv_varread_f(&sVarf_dNrnGAbo, VOf(Bf11));
    __hv_line_f(&sLine_ghKOFxb1, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_nSiOVzT1, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_Dbzt47cc, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_PnWCif2J, VIf(Bf10));
    __hv_line_f(&sLine_eTi7sI62, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_FjUzco6L, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_pIzFWcdq, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_WMoQyH4B, VIf(Bf10));
    __hv_line_f(&sLine_AtLrx3Uu, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_oChtKpu6, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_yUd5nh7M, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_goX0loNs, VIf(Bf10));
    __hv_varwrite_f(&sVarf_GVjrAeMz, VIf(Bf0));
    __hv_varwrite_f(&sVarf_GFXNJopk, VIf(Bf1));
    __hv_varwrite_f(&sVarf_QVds9Lo7, VIf(Bf2));
    sEnv_process(this, &sEnv_Hxly4jhx, VIf(Bf3), &sEnv_Hxly4jhx_sendMessage);
    sEnv_process(this, &sEnv_PsiloXPw, VIf(I0), &sEnv_PsiloXPw_sendMessage);
    __hv_line_f(&sLine_g92ffEJn, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_SexjhENi, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_dBu7QHe5, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_dFzvdCcI, VOf(Bf3));
    __hv_line_f(&sLine_Dwp8PRi8, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_cahU502u, VIf(Bf0));
    __hv_varwrite_f(&sVarf_dFzvdCcI, VIf(Bf4));
    __hv_varwrite_f(&sVarf_Ulk5uPji, VIf(Bf5));
    __hv_varwrite_f(&sVarf_o6jopTFw, VIf(Bf6));
    __hv_varread_f(&sVarf_o6jopTFw, VOf(Bf6));
    __hv_line_f(&sLine_2wwURlBG, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_5Y1IvyHR, VIf(Bf4));
    __hv_varread_f(&sVarf_Ulk5uPji, VOf(Bf4));
    __hv_line_f(&sLine_xW3tBmRS, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_69OhjOjN, VIf(Bf4));
    __hv_varwrite_f(&sVarf_iXiw9Imv, VIf(Bf2));
    __hv_varwrite_f(&sVarf_rb8LS7vM, VIf(I1));
    __hv_varread_f(&sVarf_LTJqkXRE, VOf(Bf2));
    __hv_varread_f(&sVarf_UC8fpQuT, VOf(Bf4));
    __hv_varread_f(&sVarf_XNKXj2tx, VOf(Bf0));
    __hv_varread_f(&sVarf_OqwDNWbK, VOf(Bf5));
    __hv_varread_f(&sVarf_SyQSIX44, VOf(Bf3));
    __hv_varread_f(&sVarf_3InieQot, VOf(Bf6));
    __hv_varread_f(&sVarf_0t3PnL7m, VOf(Bf1));
    __hv_varwrite_f(&sVarf_Spazrv2W, VIf(I1));
    __hv_varread_f(&sVarf_50TjPITs, VOf(Bf10));
    __hv_line_f(&sLine_xRCNKAiV, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_ombuZfhn, VOf(Bf7));
    __hv_line_f(&sLine_2DUKyMnn, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Ik54HRX3, VOf(Bf11));
    __hv_line_f(&sLine_p4HlA1fN, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_OqwDNWbK, VIf(Bf12));
    __hv_varread_f(&sVarf_Spazrv2W, VOf(Bf12));
    __hv_line_f(&sLine_b93oX8Y2, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_5zOCWLRH, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_6MK3CGfV, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_SyQSIX44, VIf(Bf9));
    __hv_line_f(&sLine_yk3dPYAK, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_9qsjlaBI, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_Ad8CeIzW, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_3InieQot, VIf(Bf9));
    __hv_line_f(&sLine_3V9P6SQX, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_W2INDvIn, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_GOkA6V4A, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_0t3PnL7m, VIf(Bf9));
    __hv_varwrite_f(&sVarf_50TjPITs, VIf(Bf2));
    __hv_varwrite_f(&sVarf_ombuZfhn, VIf(Bf4));
    __hv_varwrite_f(&sVarf_Ik54HRX3, VIf(Bf0));
    sEnv_process(this, &sEnv_1ZnTEuiT, VIf(Bf5), &sEnv_1ZnTEuiT_sendMessage);
    sEnv_process(this, &sEnv_SnEnyBoq, VIf(I1), &sEnv_SnEnyBoq_sendMessage);
    __hv_line_f(&sLine_LdmqfWFX, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_B5I84ytm, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_hpTh4Ytd, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_fCZrfLAQ, VOf(Bf5));
    __hv_line_f(&sLine_PnNpVpFW, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_LTJqkXRE, VIf(Bf2));
    __hv_varwrite_f(&sVarf_fCZrfLAQ, VIf(Bf3));
    __hv_varwrite_f(&sVarf_1ZCKJEhS, VIf(Bf6));
    __hv_varwrite_f(&sVarf_v8hwxjHS, VIf(Bf1));
    __hv_varread_f(&sVarf_v8hwxjHS, VOf(Bf1));
    __hv_line_f(&sLine_0VYqAjIM, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_XNKXj2tx, VIf(Bf3));
    __hv_varread_f(&sVarf_1ZCKJEhS, VOf(Bf3));
    __hv_line_f(&sLine_knYjdpVR, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_UC8fpQuT, VIf(Bf3));
    __hv_varwrite_f(&sVarf_ij5EqgZS, VIf(Bf0));
    __hv_varread_f(&sVarf_rb8LS7vM, VOf(Bf0));
    __hv_line_f(&sLine_f4TJHnxd, VOf(Bf3));
    __hv_varread_f(&sVarf_ij5EqgZS, VOf(Bf2));
    __hv_line_f(&sLine_qyu3YKcR, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_H9wgMv10, VOf(Bf2));
    __hv_varread_f(&sVarf_iXiw9Imv, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
